import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
with open("autodocs/xyz_py.md","r", encoding="utf-8") as fh:
    long_description += fh.read()

setuptools.setup(
    name="xyz_py",
    version="0.0.20",
    author="Jon Kragskow",
    author_email="jonkragskow@gmail.com",
    description="A package for manipulating xyz files and chemical structures",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/jonkragskow/xyz_py",
    project_urls={
        "Bug Tracker": "https://github.com/jonkragskow/xyz_py/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    package_dir={"":"xyz_py"},
    packages=setuptools.find_packages(),
    python_requires=">=3.6",
    install_requires=["numpy", "scipy", "ase"]
)
